//
//  ContentView.swift
//  LabeledContentDemo
//
//  Created by Gabriel Theodoropoulos.
//  https://serialcoder.dev
//

import SwiftUI

struct ContentView: View {
    @State private var networkStatus: String = "Connected"
    
    var body: some View {
        //
        // NOTE: Uncomment any code block next to see it working.
        //
        VStack {
            // MARK: - Simple values initializer
            LabeledContent("Network Status", value: "Connected")
            
            
            // MARK: - Changing content value dynamically
//            LabeledContent("Network Status", value: networkStatus)
//            
//            Picker("What's your status?", selection: $networkStatus) {
//                Text("Connected").tag("Connected")
//                Text("Disconnected").tag("Disconnected")
//                Text("Error").tag("Error")
//            }
            
            
            // MARK: - Custom content
//            LabeledContent("Get Lifetime Access") {
//                Button("$2.99") { }
//                    .buttonStyle(.borderedProminent)
//                    .tint(.indigo)
//            }
//            .font(.headline)
            
            
            // MARK: - Custom label and content
//            LabeledContent {
//                Button("View") { }
//            } label: {
//                Label("Settings", systemImage: "gear")
//            }
            
            
            // MARK: - Label with title and subtitle
//            LabeledContent {
//                Button("Start Now") { }
//            } label: {
//                Text("Free Trial")
//                Text("5 days full access")
//            }
            
            // MARK: - Label with three levels of subtitles
//            LabeledContent {
//                Text("Content")
//            } label: {
//                Text("Title")
//                Text("Subtitle 1")
//                Text("Subtitle 2")
//                Text("Subtitle 3")
//            }
            
            
            // MARK: - Formatted value
//            LabeledContent("Progress", value: 45, format: .percent)
            
            
            // MARK: - Using a custom style
//            LabeledContent {
//                Button("View") { }
//            } label: {
//                Label("Settings", systemImage: "gear")
//            }
//            .labeledContentStyle(CustomLabeledContentStyle())
        }
        .padding()
    }
}

#Preview {
    ContentView()
}


// MARK: - CustomLabeledContentStyle
struct CustomLabeledContentStyle: LabeledContentStyle {
    func makeBody(configuration: Configuration) -> some View {
        VStack(spacing: 12) {
            configuration.label
                .font(.headline)
                .foregroundStyle(.opacity(0.75))
            
            configuration.content
                .fontWeight(.bold)
        }
        .padding()
        .frame(width: 200)
        .background(.black.opacity(0.15))
        .clipShape(.rect(cornerRadius: 8))
    }
}
